
local _, TzTB = ...

-----------------------------------------
-- TzTanaanBonusPanel_CreateBackground --
-----------------------------------------
local function TzTanaanBonusPanel_CreateBackground( _panel, _name, _parent, _text )
	local head = TzTB.panel:CreateFontString( _panel:GetName() .. "_" .. _name .. "_Head", "ARTWORK", "GameFontNormal" )
	head:ClearAllPoints()
	head:SetPoint( "TOPLEFT", _parent:GetName(), "BOTTOMLEFT", 16, -8 )
	head:SetText( _text )

	local background = CreateFrame( "Frame", _panel:GetName() .. "_" .. _name .. "_Background", _panel )
	background:SetSize( 308, 62 )
	background:SetBackdrop( {	bgFile = "Interface/TutorialFrame/TutorialFrameBackground",
								edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
								tile = true,
								tileSize = 8,
								edgeSize = 14,
								insets = { left = 3, right = 3, top = 3, bottom = 3 } } )
	background:ClearAllPoints()
	background:SetPoint( "TOPLEFT", head:GetName(), "BOTTOMLEFT", -16, -2 )

	return background
end

------------------------------------------
-- TzTanaanBonusPanel_CreateCheckButton --
------------------------------------------
local function TzTanaanBonusPanel_CreateCheckButton( _panel, _name, _parent, _text )
	local checkbutton = CreateFrame( "CheckButton", _panel:GetName() .. "_" .. _name .. "_CheckButton", _parent, "OptionsCheckButtonTemplate" )
	checkbutton:ClearAllPoints()
	checkbutton:SetPoint( "TOPLEFT", _parent:GetName(), "TOPLEFT", 18, -18 )

	parent = TzTB.panel.dailybonus.checkbutton

	checkbutton.text = TzTB.panel.dailybonus.background:CreateFontString( _panel:GetName() .. "_" .. _name .. "_CheckButton_Text", "ARTWORK", "GameFontHighlight" )
	checkbutton.text:ClearAllPoints()
	checkbutton.text:SetPoint( "LEFT", checkbutton:GetName(), "RIGHT", 0, 1 )
	checkbutton.text:SetText( _text )

	return checkbutton
end

-------------------------------------
-- TzTanaanBonusPanel_CreateSlider --
-------------------------------------
local function TzTanaanBonusPanel_CreateSlider( _panel, _name, _background, _text, _low, _high )
	local slider = CreateFrame( "Slider", _panel:GetName() .. "_" .. _name .. "_Slider", _panel, "OptionsSliderTemplate" )

	slider:ClearAllPoints()
	slider:SetPoint( "TOPLEFT", _background:GetName(), "TOPLEFT", 128, -24 )
	slider:SetMinMaxValues( 1, 64 )
	slider:SetValueStep( 1 )

	getglobal( slider:GetName() .. "Low" ):SetText( _low )
	getglobal( slider:GetName() .. "High" ):SetText( _high )
	getglobal( slider:GetName() .. "Text" ):SetText( _text )

	parent = TzTB.panel.dailybonus.slider

	slider.value = _background:CreateFontString( _panel:GetName() .. "_" .. _name .. "_Slider_Value", "ARTWORK", "GameFontHighlight" )
	slider.value:ClearAllPoints()
	slider.value:SetPoint( "CENTER", slider:GetName(), "CENTER", 0, -12 )
	slider.value:SetText( "16" )

	slider:SetScript( "OnValueChanged",
	function( _self, _value )
-- ValueStep bug fix begin
		if not _self._onsetting then
			_self._onsetting = true
			_self:SetValue( _self:GetValue() )
			_value = _self:GetValue()
			_self._onsetting = false
		else
			return
		end
-- ValueStep bug fix end

		slider.value:SetText( _value )
	end )

	return slider
end

-------------------------------
-- TzTanaanBonusPanel_OnLoad --
-------------------------------
function TzTanaanBonusPanel_OnLoad( _self )
	TzTB.panel = _self
	TzTB.panel:RegisterEvent( "ADDON_LOADED" )

	TzTB.panel.name = "Tz: TanaanBonus"
	TzTB.panel.okay = function ( _self ) TzTanaanBonusPanel_OnOkay() end
	TzTB.panel.cancel = function ( _self ) TzTanaanBonusPanel_OnCancel() end
	InterfaceOptions_AddCategory( TzTB.panel )

	TzTB.panel.head = TzTB.panel:CreateFontString( TzTB.panel:GetName() .. "_Head", "ARTWORK", "GameFontNormalLarge" )
	TzTB.panel.head:ClearAllPoints()
	TzTB.panel.head:SetPoint( "TOPLEFT", TzTB.panel, "TOPLEFT", 16, -16 )
	TzTB.panel.head:SetText( TzTB.panel.name )

----------------------------------------------------------------
-- Daily Bonus Objectives

	TzTB.panel.dailybonus				= {}
	TzTB.panel.dailybonus.background	= TzTanaanBonusPanel_CreateBackground( TzTB.panel, "DailyBonus", TzTB.panel.head, "Daily Bonus Objective Icons" )
	TzTB.panel.dailybonus.checkbutton	= TzTanaanBonusPanel_CreateCheckButton( TzTB.panel, "DailyBonus", TzTB.panel.dailybonus.background, "Show" )
	TzTB.panel.dailybonus.slider		= TzTanaanBonusPanel_CreateSlider( TzTB.panel, "DailyBonus", TzTB.panel.dailybonus.background, "Icon Scale", "1", "64" )

----------------------------------------------------------------
-- World Bosses

	TzTB.panel.worldbosses				= {}
	TzTB.panel.worldbosses.background	= TzTanaanBonusPanel_CreateBackground( TzTB.panel, "WorldBosses", TzTB.panel.dailybonus.background, "World Boss Icons" )
	TzTB.panel.worldbosses.checkbutton	= TzTanaanBonusPanel_CreateCheckButton( TzTB.panel, "WorldBosses", TzTB.panel.worldbosses.background, "Show" )
	TzTB.panel.worldbosses.slider		= TzTanaanBonusPanel_CreateSlider( TzTB.panel, "WorldBosses", TzTB.panel.worldbosses.background, "Icon Scale", "1", "64" )

----------------------------------------------------------------
-- Elite Rares

	TzTB.panel.eliterares				= {}
	TzTB.panel.eliterares.background	= TzTanaanBonusPanel_CreateBackground( TzTB.panel, "EliteRares", TzTB.panel.worldbosses.background, "Elite Rare Icons" )
	TzTB.panel.eliterares.checkbutton	= TzTanaanBonusPanel_CreateCheckButton( TzTB.panel, "EliteRares", TzTB.panel.eliterares.background, "Show" )
	TzTB.panel.eliterares.slider		= TzTanaanBonusPanel_CreateSlider( TzTB.panel, "EliteRares", TzTB.panel.eliterares.background, "Icon Scale", "1", "64" )

----------------------------------------------------------------
-- Toy Rares

	TzTB.panel.toyrares					= {}
	TzTB.panel.toyrares.background		= TzTanaanBonusPanel_CreateBackground( TzTB.panel, "ToyRares", TzTB.panel.eliterares.background, "Toy Rare Icons" )
	TzTB.panel.toyrares.checkbutton		= TzTanaanBonusPanel_CreateCheckButton( TzTB.panel, "ToyRares", TzTB.panel.toyrares.background, "Show" )
	TzTB.panel.toyrares.slider			= TzTanaanBonusPanel_CreateSlider( TzTB.panel, "ToyRares", TzTB.panel.toyrares.background, "Icon Scale", "1", "64" )

----------------------------------------------------------------
-- Pet Rares

	TzTB.panel.petrares					= {}
	TzTB.panel.petrares.background		= TzTanaanBonusPanel_CreateBackground( TzTB.panel, "PetRares", TzTB.panel.toyrares.background, "Pet Rare Icons" )
	TzTB.panel.petrares.checkbutton		= TzTanaanBonusPanel_CreateCheckButton( TzTB.panel, "PetRares", TzTB.panel.petrares.background, "Show" )
	TzTB.panel.petrares.slider			= TzTanaanBonusPanel_CreateSlider( TzTB.panel, "PetRares", TzTB.panel.petrares.background, "Icon Scale", "1", "64" )
end

--------------------------------
-- TzTanaanBonusPanel_OnEvent --
--------------------------------
function TzTanaanBonusPanel_OnEvent( _self, _event, _name )
	if( _event == "ADDON_LOADED" and _name == "TzTanaanBonus" ) then

		if TzTanaanBonusOptions						== nil then	TzTanaanBonusOptions = {}						end
		if TzTanaanBonusOptions.worldbosses_show	== nil then	TzTanaanBonusOptions.worldbosses_show	= true	end
		if TzTanaanBonusOptions.worldbosses_scale	== nil then	TzTanaanBonusOptions.worldbosses_scale	= 32	end
		if TzTanaanBonusOptions.dailybonus_show		== nil then	TzTanaanBonusOptions.dailybonus_show	= true	end
		if TzTanaanBonusOptions.dailybonus_scale	== nil then	TzTanaanBonusOptions.dailybonus_scale	= 32	end
		if TzTanaanBonusOptions.eliterares_show		== nil then	TzTanaanBonusOptions.eliterares_show	= true	end
		if TzTanaanBonusOptions.eliterares_scale	== nil then	TzTanaanBonusOptions.eliterares_scale	= 32	end
		if TzTanaanBonusOptions.petrares_show		== nil then	TzTanaanBonusOptions.petrares_show		= true	end
		if TzTanaanBonusOptions.petrares_scale		== nil then	TzTanaanBonusOptions.petrares_scale		= 32	end
		if TzTanaanBonusOptions.toyrares_show		== nil then	TzTanaanBonusOptions.toyrares_show		= true	end
		if TzTanaanBonusOptions.toyrares_scale		== nil then	TzTanaanBonusOptions.toyrares_scale		= 32	end

		TzTanaanBonusPanel_OnCancel()
	end
end

-------------------------------
-- TzTanaanBonusPanel_OnOkay --
-------------------------------
function TzTanaanBonusPanel_OnOkay( _self )
	TzTanaanBonusOptions.worldbosses_show	= TzTB.panel.worldbosses.checkbutton:GetChecked()
	TzTanaanBonusOptions.worldbosses_scale	= TzTB.panel.worldbosses.slider:GetValue()
	TzTanaanBonusOptions.dailybonus_show	= TzTB.panel.dailybonus.checkbutton:GetChecked()
	TzTanaanBonusOptions.dailybonus_scale	= TzTB.panel.dailybonus.slider:GetValue()
	TzTanaanBonusOptions.eliterares_show	= TzTB.panel.eliterares.checkbutton:GetChecked()
	TzTanaanBonusOptions.eliterares_scale	= TzTB.panel.eliterares.slider:GetValue()
	TzTanaanBonusOptions.petrares_show		= TzTB.panel.petrares.checkbutton:GetChecked()
	TzTanaanBonusOptions.petrares_scale		= TzTB.panel.petrares.slider:GetValue()
	TzTanaanBonusOptions.toyrares_show		= TzTB.panel.toyrares.checkbutton:GetChecked()
	TzTanaanBonusOptions.toyrares_scale		= TzTB.panel.toyrares.slider:GetValue()
end

---------------------------------
-- TzTanaanBonusPanel_OnCancel --
---------------------------------
function TzTanaanBonusPanel_OnCancel( _self )
	TzTB.panel.worldbosses.checkbutton:SetChecked(	TzTanaanBonusOptions.worldbosses_show )
	TzTB.panel.worldbosses.slider:SetValue(			TzTanaanBonusOptions.worldbosses_scale )
	TzTB.panel.dailybonus.checkbutton:SetChecked(	TzTanaanBonusOptions.dailybonus_show )
	TzTB.panel.dailybonus.slider:SetValue(			TzTanaanBonusOptions.dailybonus_scale )
	TzTB.panel.eliterares.checkbutton:SetChecked(	TzTanaanBonusOptions.eliterares_show )
	TzTB.panel.eliterares.slider:SetValue(			TzTanaanBonusOptions.eliterares_scale )
	TzTB.panel.petrares.checkbutton:SetChecked(		TzTanaanBonusOptions.petrares_show )
	TzTB.panel.petrares.slider:SetValue(			TzTanaanBonusOptions.petrares_scale )
	TzTB.panel.toyrares.checkbutton:SetChecked(		TzTanaanBonusOptions.toyrares_show )
	TzTB.panel.toyrares.slider:SetValue(			TzTanaanBonusOptions.toyrares_scale )
end
